==> opennebula-6.99.85-1-amd64.tar.gz: opennebula-6.99.85/src/fireedge/src/client/assets/languages/fr_FR.js <==
lang="fr_FR"
locale={
  "":"",
  "children":"fils",
  "Delete":"Supprimer",
  "VMs":"Machines Virtuelles",
  "Images":"Images",
  "Users":"Utilisateurs",
  "Groups":"Groupes",
  "Datastores":"Espaces de stockage",
  "Clusters":"Grappes",
  "Services":"Services",
  "Zones":"Zones",
  "VDCs":"VDCs",
  "Virtual Routers":"Routeurs Virtuels",
  "Apps":"Applications",
  "VM Groups":"Groupes de VM",
  "Identifier":"Identifiant",
  "All":"Tout",
  "Use":"Utiliser",
  "Admin":"Admin",
  "Size":"Taille",
  "First":"Premier",
  "Last":"Dernier",
  "Total leases":"Baux totaux",
  "Remove":"Retirer",
  "Clone":"Clone",
  "Tiers":"Tiers",
  "Group":"Groupe",
  "Provision ID":"ID de provisionnement",
  "Datastore":"Espace de stockage",
  "Monitoring":"Supervision",
  "Disk size":"Taille de disque",
  "Cluster":"Grappe",
  "Version":"Version",
  "Zone":"Zone",
  "Short address":"Adresse courte",
  "Class":"Classe",
  "Total error VMs":"Nombre total de VMs en erreur",
  "Virtual CPU":"CPU virtuel",
  "IP":"IP",
  "text":"texte",
  "finalWord":"MotFinal",
  "Export":"Exporter",
  "EndDate":"DateDeFin",
  "title":"titre",
  "tooltip":"infobulle",
  "Submit":"Soumettre",
  "Protocol":"Protocole",
  "Type":"Type",
  "Range":"Plage",
  "ICMP Type":"Type ICMP",
  "ICMPv6 Type":"Type ICMPv6",
  "PROTOCOL":"PROTOCOLE",
  "RANGE":"INTERVAL",
  "Description":"Description",
  "Mandatory":"Obligatoire",
  "Yes":"Oui",
  "No":"Non",
  "Extra":"Extra",
  "Expression":"Expression",
  "Adjust":"Ajuster",
  "Period":"Periode",
  "Min":"Min",
  "TIMEFORMAT":"FORMATTEMPS",
  "Time Expression":"Expression du temps",
  "Time Format":"Format de temps",
  "Alias":"Alias",
  "Rows per page":"Lignes par page",
  "RDP":"RDP",
  "ID":"ID",
  "Name":"Nom",
  "Number of VMs":"Nombre de VMs",
  "Min VMs":"VMs min",
  "Max VMs":"VMs max",
  "Add Charters Values Configuration":"Ajouter les valeurs de configuration charters",
  "RDP connection":"Connexion RDP",
  "SSH connection":"Connexion SSH",
  "Search":"Rechercher",
  "Value":"Valeur",
  "Warning before":"Avertir avant",
  "Potential Use Cases":"",
  "Add Group":"",
  "Affined Groups":"",
  "Host Affinity":"",
  "Add":"Ajouter",
  "Status":"Statut",
  "Policy":"Politique",
  "Affined Hosts":"",
  "VM Group Configuration":"",
  "New Role":"",
  "None":"Aucun",
  "Show all":"Tout afficher",
  "Show all owned by the user or his groups":"",
  "Show all owned by the user":"",
  "Back":"Retour",
  "Divide Window":"",
  "Low":"",
  "Medium":"",
  "High":"",
  "tooltipTitle":"",
  "Persistent":"Persistant",
  "Non Persistent":"",
  "Disk type":"Type de disque",
  "Running":"En cours",
  "Total":"Total",
  "Provider":"Fournisseur",
  "Menu":"",
  "Show columns":"",
  "Manage columns":"",
  "Filter":"Filtrer",
  "Hide column":"",
  "Unsort":"",
  "Sort by ASC":"",
  "Sort by DESC":"",
  "Sort":"",
  "Refresh":"Actualiser",
  "Previous":"",
  "of":"",
  "Next":"Suivant",
  "Download Default Image":"",
  "Total VMs":"Total des VMs",
  "Filters":"Filtres",
  "Endpoint":"Terminaison",
  "value":"",
  "Group By":"",
  "User":"Utilisateur",
  "Chart Type":"",
  "Line Chart":"",
  "Bar Chart":"",
  "Area Chart":"",
  "Table Chart":"",
  "Attributes":"Attributs",
  "name":"nom",
  "Permissions":"Autorisations",
  "Free CPU":"CPU libre",
  "Used CPU":"",
  "Free Memory":"",
  "Information":"Information",
  "Flatten":"Aplati",
  "Revert":"Revenir",
  "Apply":"Appliquer",
  "How to use Quota Controls":"",
  "enter Resource IDs over which this quota will apply":"",
  "this further qualifies the quota type to a more specific attribute":"",
  "Resource IDs":"",
  "Select or type a Resource ID":"",
  "VM Quota":"",
  "Datastore Quota":"",
  "Network Quota":"",
  "Image Quota":"",
  "Quota Controls":"",
  "Severity":"",
  "All Severities":"",
  "Asc":"",
  "Desc":"",
  "Force":"Force",
  "Scale":"Ajustement",
  "Attachments":"",
  "Add comment to close the ticket":"",
  "Authentication":"Authentification",
  "Password":"Mot de passe",
  "Edit Public SSH Key":"",
  "Edit Private SSH Key":"",
  "Edit SSH Key Passphrase":"",
  "Save Changes":"",
  "Cancel":"Annuler",
  "Save":"Enregistrer",
  "Primary":"Primaire",
  "Secondary":"",
  "Action":"Action",
  "Cores":"Coeurs",
  "Sockets":"Sockets",
  "Save as":"Enregistrer sous",
  "Resize":"Redimensionner",
  "Other":"Autre",
  "Locate on table":"Localiser dans la table",
  "Close":"Fermer",
  "Wrong username or password":"",
  "Credentials":"Identifiants",
  "Succesfully changed password":"",
  "Token":"Jeton",
  "Get a new token":"Obtenir un nouveau jeton",
  "Scan this Qr":"",
  "Clear error messages and warnings from selects Virtual Machines":"",
  "Daily":"",
  "Weekly":"Hebdomadaire",
  "Monthly":"Mensuel",
  "Yearly":"Annuel",
  "On":"Actif",
  "VMRC":"VMRC",
  "Charter":"Charter",
  "Active":"Actif",
  "Reconnect":"Reconnecter",
  "Part of":"Fait parti de",
  "Made with":"Fait avec",
  "Clear":"Nettoyer",
  "Finish":"Finir",
  "Context":"Contexte",
  "Backup":"Sauvegarde",
  "Volatile disk":"Disque volatile",
  "Switch group":"Changer de groupe",
  "Sign Out":"Quitter",
  "Switch view":"Changer de vue",
  "More":"Plus",
  "description":"description",
  "No labels":"",
  "Sort by":"",
  "message":"message",
  "Cannot connect to OneFlow server":"Impossible de joindre le serveur OneFlow",
  "Retry":"",
  "col":"col",
  "Hugepage":"Hugepage",
  "Free":"libre",
  "Pages":"Pages",
  "Usage":"Utilisation",
  "Prolog":"Prologue",
  "Dismiss":"Acquitter",
  "Sign In":"Identification",
  "Add IP":"Ajouter lIP",
  "Login Token":"Jeton de connexion",
  "Enter Verification Code":"",
  "Register authentication App":"",
  "Or":"",
  "Get an account":"",
  "Commercial Support":"",
  "Additional Help Resources":"",
  "Documentation":"Documentation",
  "Commercial Support Requests":"",
}

==> opennebula-7.1.80-1-amd64.tar.gz: opennebula-7.1.80/src/fireedge/src/client/assets/languages/fr_FR.js <==
lang="fr_FR"
locale={
  "":"",
  "children":"fils",
  "Delete":"Supprimer",
  "VMs":"Machines Virtuelles",
  "Images":"Images",
  "Users":"Utilisateurs",
  "Groups":"Groupes",
  "Datastores":"Espaces de stockage",
  "Clusters":"Grappes",
  "Services":"Services",
  "Zones":"Zones",
  "VDCs":"VDCs",
  "Virtual Routers":"Routeurs Virtuels",
  "Apps":"Applications",
  "VM Groups":"Groupes de VM",
  "Identifier":"Identifiant",
  "All":"Tout",
  "Use":"Utiliser",
  "Admin":"Admin",
  "Size":"Taille",
  "First":"Premier",
  "Last":"Dernier",
  "Total leases":"Baux totaux",
  "Remove":"Retirer",
  "Clone":"Clone",
  "Tiers":"Tiers",
  "Group":"Groupe",
  "Provision ID":"ID de provisionnement",
  "Datastore":"Espace de stockage",
  "Monitoring":"Supervision",
  "Disk size":"Taille de disque",
  "Cluster":"Grappe",
  "Version":"Version",
  "Zone":"Zone",
  "Short address":"Adresse courte",
  "Class":"Classe",
  "end":"fin",
  "Total error VMs":"Nombre total de VMs en erreur",
  "Virtual CPU":"CPU virtuel",
  "IP":"IP",
  "text":"texte",
  "finalWord":"MotFinal",
  "Export":"Exporter",
  "EndDate":"DateDeFin",
  "title":"titre",
  "tooltip":"infobulle",
  "Protocol":"Protocole",
  "Type":"Type",
  "Range":"Plage",
  "ICMP Type":"Type ICMP",
  "ICMPv6 Type":"Type ICMPv6",
  "PROTOCOL":"PROTOCOLE",
  "RANGE":"INTERVAL",
  "Adjust":"Ajuster",
  "Min":"Min",
  "Period":"Periode",
  "Expression":"Expression",
  "format":"format",
  "Time Format":"Format de temps",
  "Time Expression":"Expression du temps",
  "Add Charters Values Configuration":"Ajouter les valeurs de configuration charters",
  "Warning before":"Avertir avant",
  "Add Group":"Ajouter un Groupe",
  "ID":"ID",
  "Name":"Nom",
  "Status":"Statut",
  "Rows per page":"Lignes par page",
  "Policy":"Politique",
  "VM Group Configuration":"Configuration du Groupe de VM",
  "None":"Aucun",
  "RDP connection":"Connexion RDP",
  "SSH connection":"Connexion SSH",
  "Search":"Rechercher",
  "Yes":"Oui",
  "No":"Non",
  "Value":"Valeur",
  "Show all":"Tout afficher",
  "Low":"Bas",
  "Medium":"Moyen",
  "High":"Haut",
  "tooltipTitle":"TitreInfoBulle",
  "Persistent":"Persistant",
  "Non Persistent":"Non persistant",
  "Disk type":"Type de disque",
  "Running":"En cours",
  "Total":"Total",
  "Provider":"Fournisseur",
  "Menu":"Menu",
  "Show columns":"Afficher les colonnes",
  "Filter":"Filtrer",
  "Hide column":"Cacher la colonne",
  "Sort by ASC":"Tri ascendant",
  "Sort":"Trier",
  "Refresh":"Actualiser",
  "Card View":"Vue carte",
  "List View":"Vue liste",
  "Number of rows per page":"Nombre de lignes par page",
  "of":"de",
  "Filters":"Filtres",
  "Total VMs":"Total des VMs",
  "Endpoint":"Terminaison",
  "value":"valeur",
  "Group By":"Grouper par",
  "User":"Utilisateur",
  "Chart Type":"Type de graphique",
  "Line Chart":"",
  "Bar Chart":"",
  "Area Chart":"",
  "Table Chart":"",
  "Attributes":"Attributs",
  "name":"nom",
  "Permissions":"Autorisations",
  "Information":"Information",
  "Flatten":"Aplati",
  "Revert":"Revenir",
  "How to use Quota Controls":"",
  "enter Resource IDs over which this quota will apply":"",
  "this further qualifies the quota type to a more specific attribute":"",
  "VM Quota":"",
  "Datastore Quota":"",
  "Network Quota":"",
  "Image Quota":"",
  "Quota Controls":"",
  "Severity":"",
  "All Severities":"",
  "Asc":"",
  "Desc":"",
  "Number of VMs":"Nombre de VMs",
  "Force":"Force",
  "Attachments":"",
  "Add comment to close the ticket":"",
  "Authentication":"Authentification",
  "Password":"Mot de passe",
  "Edit Public SSH Key":"",
  "Edit Private SSH Key":"",
  "Edit SSH Key Passphrase":"",
  "Primary Group":"Groupe primaire",
  "Secondary Groups":"Groupes secondaires",
  "Action":"Action",
  "Cores":"Coeurs",
  "Sockets":"Sockets",
  "Alias":"Alias",
  "Save as":"Enregistrer sous",
  "Resize":"Redimensionner",
  "Back":"Retour",
  "Close":"Fermer",
  "Wrong username or password":"",
  "Primary":"Primaire",
  "Description":"Description",
  "Credentials":"Identifiants",
  "Succesfully changed password":"",
  "Token":"Jeton",
  "Scan this Qr":"",
  "Clear error messages and warnings from selects Virtual Machines":"",
  "Charter":"Charter",
  "Active":"Actif",
  "Reconnect":"Reconnecter",
  "Submit":"Soumettre",
  "Part of":"Fait parti de",
  "Made with":"Fait avec",
  "Cancel":"Annuler",
  "Clear":"Nettoyer",
  "Finish":"Finir",
  "Next":"Suivant",
  "Add":"Ajouter",
  "Context":"Contexte",
  "Volatile disk":"Disque volatile",
  "Switch group":"Changer de groupe",
  "Sign Out":"Quitter",
  "Switch view":"Changer de vue",
  "More":"Plus",
  "description":"description",
  "No labels":"",
  "Filter by label":"",
  "Sort by":"",
  "message":"message",
  "Cannot connect to OneFlow server":"Impossible de joindre le serveur OneFlow",
  "Retry":"",
  "col":"col",
  "Hugepage":"Hugepage",
  "Free":"libre",
  "Pages":"Pages",
  "Usage":"Utilisation",
  "Prolog":"Prologue",
  "Dismiss":"Acquitter",
  "My Dashboard":"",
  "Sign In Now":"",
  "Add IP":"Ajouter lIP",
  "Enter Verification Code":"",
  "Or":"",
  "Get an account":"",
  "Commercial Support":"",
  "Additional Help Resources":"",
  "Documentation":"Documentation",
  "Commercial Support Requests":"",
}
